#  ##### BEGIN GPL LICENSE BLOCK #####
# 
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# ##### END GPL LICENSE BLOCK #####

from .scene import Scene2D, Layer

print("""
Python module StrawberryPy, a Graphical Animation module.
Owner: Spatial Innovations <https://github.com/Spatial-Innovations>
Contributors:
    Patrick Huang <https://github.com/HuangPatrick16777216>
    Arjun Sahlot <https://github.com/ArjunSahlot>""")